@@ -26,6 +26,8 @@ class Calendar
     */
     function Calendar()
     {
+       $dayslist = _("SMTWTFS");
+       $this->dayNames = array($dayslist[0], $dayslist[1], $dayslist[2], $dayslist[3], $dayslist[4], $dayslist[5], $dayslist[6]);
     }
     
     
@@ -228,9 +230,34 @@ class Calendar
     	    $nextMonth = "";
     	}
     	
-    	$header = $monthName . (($showYear > 0) ? " " . $year : "");
+    	$header = _($monthName) . (($showYear > 0) ? " " . $year : "");
     	
-    	$s .= "<table class=\"calendar\">\n";
+        global $smallcal_separator, $smallcal_bottom;
+        if ($smallcal_separator == 1)
+        {
+    	   $s .= "<hr width='100%'>\n";
+    	   $s .= "<table class=\"calendar\" align=\"center\">\n";
+        }
+        else if ($smallcal_separator == 2)
+        {
+
+           if ($smallcal_bottom)
+              $s .= '<table height="100%" valign="bottom"><tr><td>';
+
+           global $color;
+           $s .= "<table align=center width=\"90%\" cellpadding=0 cellspacing=1 border=0 bgcolor=\"$color[9]\">";
+           $s .= '<tr><td>';
+           $s .= "<table class=\"calendar\" width=\"100%\" cellpadding=1 cellspacing=1 border=0 bgcolor=\"$color[4]\">\n";
+
+        }
+        else
+        {
+           if ($smallcal_bottom)
+              $s .= '<table height="100%" valign="bottom"><tr><td>';
+
+    	   $s .= "<table class=\"calendar\" align=\"center\">\n";
+        }
+
     	$s .= "<tr>\n";
 	$s .= "<td align=\"center\" valign=\"top\" class=\"calendarHeader\" colspan=\"7\">" . (($thisMonth == "") ? "&nbsp;" : "<a style=\"text-decoration:none\" href=\"$thisMonth\" onClick=\"parent.right.location='$thisDay'\">" . _("Today") . "</a>")  . "</td>\n";
 	//$s .= "<td align=\"center\" valign=\"top\" class=\"calendarHeader\" colspan=\"7\">" . (($thisMonth == "") ? "&nbsp;" : "<a style=\"text-decoration:none\" href=\"$thisMonth\">" . _("Today") . "</a>")  . "</td>\n";
@@ -305,7 +332,22 @@ class Calendar
     	    $s .= "</tr>\n";    
     	}
     	
-    	$s .= "</table>\n";
+        if ($smallcal_separator == 2)
+        {
+    	   $s .= "</table></td></tr>\n</table>\n";
+           if ($smallcal_bottom)
+              $s .= '</td></tr></table>';
+        }
+        else
+        {
+    	   $s .= "</table>\n";
+           if ($smallcal_separator == 0 && $smallcal_bottom)
+              $s .= '</td></tr></table>';
+        }
+
+
+
+
     	
     	return $s;  	
     }
@@ -392,7 +434,7 @@ class Calendar
         The labels to display for the days of the week. The first entry in this array
         represents Sunday.
     */
-    var $dayNames = array("S", "M", "T", "W", "T", "F", "S");
+    var $dayNames;
     
     /*
         The labels to display for the months of the year. The first entry in this array
