@@ -33,7 +33,8 @@
       global $username, $data_dir, $ShowSmallcal, $color, 
              $smallcal_cheader, $smallcal_cday, $smallcal_ctoday, 
              $smallcal_cevent, $smallcal_cshared, $smallcal_ccalendar, 
-             $smallcal_csize, $smallcal_cdefault ;
+             $smallcal_csize, $smallcal_cdefault, $smallcal_separator,
+             $smallcal_bottom;
 
 
       compatibility_sqextractGlobalVar('ShowSmallcal');
@@ -45,45 +46,59 @@
       compatibility_sqextractGlobalVar('smallcal_cshared');
       compatibility_sqextractGlobalVar('smallcal_csize');
       compatibility_sqextractGlobalVar('smallcal_ccalendar');
+      compatibility_sqextractGlobalVar('smallcal_separator');
+      compatibility_sqextractGlobalVar('smallcal_bottom');
 
 
-      if (isset($ShowSmallcal)) {
+      if (isset($smallcal_bottom) && $smallcal_bottom == 'on') {
+          setPref($data_dir, $username, 'smallcal_bottom', '1');
+      } else {
+          setPref($data_dir, $username, 'smallcal_bottom', '0');
+      }
+
+      if (isset($smallcal_separator) && !empty($smallcal_separator)) {
+          setPref($data_dir, $username, 'smallcal_separator', $smallcal_separator);
+      } else {
+          setPref($data_dir, $username, 'smallcal_separator', '0');
+      }
+
+      if (isset($ShowSmallcal) && !empty($ShowSmallcal)) {
           setPref($data_dir, $username, 'smallcal_show', '1');
       } else {
           setPref($data_dir, $username, 'smallcal_show', '');
       }
 
-      if (isset($smallcal_cdefault)) {
+      if (isset($smallcal_cdefault) && !empty($smallcal_cdefault)) {
           setPref($data_dir, $username, 'smallcal_default', '1');
       } else {
           setPref($data_dir, $username, 'smallcal_default', '');
       } 
-      if (isset($smallcal_cheader)) {
+      if (isset($smallcal_cheader) && !empty($smallcal_cheader)) {
           setPref($data_dir, $username, 'smallcal_header', $smallcal_cheader);
       } else {
           setPref($data_dir, $username, 'smallcal_header', $color[11]);
       }
-      if (isset($smallcal_cday)) {
+      if (isset($smallcal_cday) && !empty($smallcal_cday)) {
           setPref($data_dir, $username, 'smallcal_day', $smallcal_cday);
       } else {
           setPref($data_dir, $username, 'smallcal_day', '');
       } 
-      if (isset($smallcal_ctoday)) {
+      if (isset($smallcal_ctoday) && !empty($smallcal_ctoday)) {
           setPref($data_dir, $username, 'smallcal_today', $smallcal_ctoday);
       } else {
           setPref($data_dir, $username, 'smallcal_today', '');
       }
-      if (isset($smallcal_cevent)) {
+      if (isset($smallcal_cevent) && !empty($smallcal_cevent)) {
           setPref($data_dir, $username, 'smallcal_event', $smallcal_cevent);
       } else {
           setPref($data_dir, $username, 'smallcal_event', '');
       }
-      if (isset($smallcal_csize)) {
+      if (isset($smallcal_csize) && !empty($smallcal_csize)) {
           setPref($data_dir, $username, 'smallcal_size', $smallcal_csize);
       } else {
           setPref($data_dir, $username, 'smallcal_size', '');
       }
-      if (isset($smallcal_cshared)) 
+      if (isset($smallcal_cshared) && !empty($smallcal_cshared)) 
       {
       	  if (! file_exists("../plugins/calendar/calendar_check.php")) 
       	  {
@@ -112,7 +127,7 @@
 
    function smallcal_pref_do() {
 
-      global $username, $data_dir, $smallcal_show, $smallcal_header, $smallcal_day, $smallcal_today, $smallcal_event, $smallcal_event_i, $smallcal_shared, $smallcal_calendar, $smallcal_size, $smallcal_default, $color ;
+      global $username, $data_dir, $smallcal_show, $smallcal_header, $smallcal_day, $smallcal_today, $smallcal_event, $smallcal_event_i, $smallcal_shared, $smallcal_calendar, $smallcal_size, $smallcal_default, $color, $smallcal_separator, $smallcal_bottom;
 
       $smallcal_show = getPref($data_dir, $username, 'smallcal_show');
       $smallcal_default = getPref($data_dir, $username, 'smallcal_default');
@@ -124,6 +139,8 @@
       $smallcal_shared = getPref($data_dir, $username, 'smallcal_shared');
       $smallcal_size = getPref($data_dir, $username, 'smallcal_size');
       $smallcal_calendar = getPref($data_dir, $username, 'smallcal_calendar');
+      $smallcal_separator = getPref($data_dir, $username, 'smallcal_separator');
+      $smallcal_bottom = getPref($data_dir, $username, 'smallcal_bottom');
 
       if (!isset($smallcal_header) || !$smallcal_header){
          $smallcal_header = $color[11];
@@ -136,6 +153,8 @@
 	 $smallcal_event_i = "italic";
 	 $smallcal_size = "";
 	 $smallcal_calendar = "Personal";
+         $smallcal_separator = 0;
+         $smallcal_bottom = 0;
       }
 
    }
@@ -144,7 +163,7 @@
       global $username, $data_dir, $smallcal_show, $smallcal_header, 
              $smallcal_day, $smallcal_today, $smallcal_event, 
              $smallcal_shared, $smallcal_calendar, $smallcal_size, 
-             $smallcal_default, $base_uri;
+             $smallcal_default, $smallcal_separator, $smallcal_bottom, $base_uri;
 
       // even if using defaults, want to make sure to 
       // show these saved values - would be a shame to
@@ -157,6 +176,8 @@
       $smallcal_event_i = "normal";
       $smallcal_size = getPref($data_dir, $username, 'smallcal_size');
       $smallcal_calendar = getPref($data_dir, $username, 'smallcal_calendar');
+      $smallcal_separator = getPref($data_dir, $username, 'smallcal_separator');
+      $smallcal_bottom = getPref($data_dir, $username, 'smallcal_bottom');
 
       echo '<tr><td colspan="2">&nbsp;</td></tr>';
       echo '<tr><td colspan="2"><hr width=400></td></tr>';
@@ -192,6 +213,43 @@
            echo " value=\"$smallcal_event\"";
       }
       echo '></td></tr>';
+      echo '<tr><td align=right nowrap>' . _("Calendar separator:") . ' </td><td><select name="smallcal_separator">';
+      if ($smallcal_separator == "" || $smallcal_separator == 0)
+      {
+          echo '<option value="0" selected>None</option>';
+      }
+      else
+      {
+          echo '<option value="0">None</option>';
+      }
+      if ($smallcal_separator == "1")
+      {
+          echo '<option value="1" selected>Horizontal rule</option>';
+      }
+      else
+      {
+          echo '<option value="1">Horizontal rule</option>';
+      }
+      if ($smallcal_separator == "2")
+      {
+          echo '<option value="2" selected>Box</option>';
+      }
+      else
+      {
+          echo '<option value="2">Box</option>';
+      }
+      echo '</select></td></tr>';
+
+/*
+      echo '<tr><td align=right nowrap>' . _("Place on Bottom:") 
+         . '</td><td><input name="smallcal_bottom" type=CHECKBOX';
+      if ($smallcal_bottom) {
+        echo ' CHECKED';
+      }
+      echo ' >'
+         . '</td><td>';
+*/
+
       echo '<tr><td align=right nowrap>' . _("Calendar size:") . ' </td><td><select name="smallcal_csize">';
       if ($smallcal_size == "")
       {
@@ -407,7 +465,7 @@
 
     function addsmallcal_left_do()
     {
-        global $data_dir, $username, $year, $month, $todayis, $calendardata, $smallcal_event, $smallcal_event_i, $smallcal_show, $smallcal_calendar, $smallcal_header, $smallcal_day, $smallcal_today, $smallcal_size ;
+        global $data_dir, $username, $year, $month, $todayis, $calendardata, $smallcal_event, $smallcal_event_i, $smallcal_show, $smallcal_calendar, $smallcal_header, $smallcal_day, $smallcal_today, $smallcal_size, $smallcal_separator, $smallcal_bottom;
 
         compatibility_sqextractGlobalVar('month');
         compatibility_sqextractGlobalVar('year');
