@@ -75,4 +75,13 @@
     
    }
 
+
+   function smallcal_version()
+   {
+
+      return '0.8';
+
+   }
+
+
 ?>
